! 25 Aug 87
! log.cmd - any-user login to UNIX systems
! usage: term log username [password]
!
remark Any-user login to UNIX Systems
baud 9600
parity NONE
wordlen 8
stopbits 1
mode FULL
emulate VT100
protocol ASCII
if "$2"=""
	login "^L06^T01\r^Sogin:^S^W$1\r"
else
	login "^L06^T01\r^Sogin:^S^W$1\r^Sword:^S^W$2\r"
endif
call NONE
