:
# 20 May 89
# Name:	autopoll.sh
# Usage: run
#	"autopoll.sh </dev/null >/dev/null 2&>>/usr/term/cronerrs"
#	from CRON.  For debugging, change /dev/null to /dev/console,
#	and -q to -e below.
# Purpose: TERM's automated polling scripts from CRON
# 
PATH=:/usr/bin:/bin:/etc::	# add others if you want
export PATH
TERM=vt100			# or your terminal type
export TERM
term -q autopoll infile outfile	# change infile and outfile to your own
#
# to run term again on failed requests, uncomment the following line(s)
#sleep 3600			# 1 hour later
#term -q autopoll outfile outfile2
