! 14 Jan 91
! IBM 3270/950 Emulation through 7171 protocol converter
!
! The IBM Mainframe may be accessed as a 3270 keyboard, with a
! Televideo 950 used for screen addressing and control.
!
!				  IBM 3270	PC		Term
!				  Key		Key		KeyName
!				  --------	--------	--------
emulate tv950
setkey kp+	"^Z"		! clear		kp+		kp+
setkey kpenter	"^Z"		! clear		kpenter		kpenter
setkey c-home	"^Z"		! clear		c-home		c-home
setkey cf5	"^A,^M"		! PA1		cf5		cf5
setkey cf6	"^A.^M"		! PA2		cf6		cf6
setkey cf7	"^A/^M"		! PA3		cf7		cf7
				! Delete Char	del		del
setkey ins	"\eE"		! Toggle Ins	ins		ins
setkey end	"\eR"		! Erase EOF	end		end
setkey c-end	"\eR"		! Erase EOF	c-end		c-end
setkey cf8	"\e\eR"		! Erase Input	cf8		cf8
				! Cursor Up	up		up
				! Cursor Down	down		down
				! Cursor Left	left		left
				! Cursor Right	right		right
				! Home		home		home
				! PF1-PF10	f1-f10		f1-f10
setkey f11	"^AJ^M"		! PF11		f11		f11
setkey sf1	"^AJ^M"		! PF11		sf1		sf1
setkey f12	"\eQ"		! PF12		f12		f12
setkey sf2	"\eQ"		! PF12		sf2		sf2
setkey sf3	"^A`^M"		! PF13		sf3		sf3
setkey sf4	"^Aa^M"		! PF14		sf4		sf4
setkey sf5	"^Ab^M"		! PF15		sf5		sf5
setkey sf6	"^Ac^M"		! PF16		sf6		sf6
setkey sf7	"^Ad^M"		! PF17		sf7		sf7
setkey sf8	"^Ae^M"		! PF18		sf8		sf8
setkey sf9	"^Af^M"		! PF19		sf9		sf9
setkey sf10	"^Ag^M"		! PF20		sf10		sf10
setkey cf1	"^Ah^M"		! PF21		cf1		cf1
setkey sf11	"^Ah^M"		! PF21		sf11		sf11
setkey cf2	"^Ai^M"		! PF22		cf2		cf2
setkey sf12	"^Ai^M"		! PF22		sf12		sf12
setkey cf3	"^Aj^M"		! PF23		cf3		cf3
setkey cf4	"\eq"		! PF24		cf4		cf4
setkey cf9	"^I"		! Column Tab	cf9		cf9
setkey cf10	"\eI"		! Col Backtab	cf10		cf10
setkey c-pgup	"\eY"		! Indent	c-pgup		c-pgup
setkey c-pgdn	"\ey"		! Undent	c-pgdn		c-pgdn
setkey tab	"\eT"		! Tab		tab		tab
setkey s-tab	"\et"		! Field Backtab	s-tab		s-tab
				! Newline	^J		^J
				! Typeahead Purge ^X		^X
				! Pacing start	^S		^S
				! Pacing Stop	^Q		^Q
				! Keyboard Unlock ^T		^T
				! Char-error reset ^R		^R
				! Master reset	^G		^G
				! Redisplay	Esc *		Esc *
return
